@@ -63,7 +63,7 @@ function reloadGraphs(max_image_width) {
             }
             url_click = $(this).attr('data-href-click');
             // Remove a previous image that's already there.
-            $('~ img', this).remove();
+            // PROBABLY NOT NEEDED $('~ img', this).remove();
             timestamp = new Date().getTime();  // No cached images.
             html_url = url +
                 amp_or_questionmark + 'width=' + width +
@@ -73,6 +73,7 @@ function reloadGraphs(max_image_width) {
                 '/>';
             // Remove progress animation and possibly old images.
             $main_tag.parent().find(".auto-inserted").remove();
+
             // Add progress animation.
             $(this).after('<div class="auto-inserted"><img src="/static_media/lizard_ui/ajax-loader.gif" class="progress-animation" data-src="' + html_url + '" /></div>');
 
